/* Simple ID3 editor for DOS
   By Matt Craven
   (c)2000 Hedgehog Software

   Suggested by Burnfire
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <conio.h>
#include "id3.h"

float id3edit_version = 0.1;     /* Program Version number */

/*===================================================================
  id3e_get_limited_input(txt, maxlen)

  Gets input from the user into "txt".  It won't let the input exceed
  "maxlen" characters, and it'll pad the string with spaces to fill
  "maxlen".
  =================================================================*/

void id3e_get_limited_input(char *txt, int maxlen)
{
   char ch = 0;
   int pos = 0;

   do
   {
      /* Get keypress */
      ch = getch();

      if(ch == 27)
      {
         /* quit */
         exit(0);
      }

      if(ch == 8)
      {
         /* delete */
         if(pos > 0)
            pos--;

         printf("%c",8);
         printf(" ");
         printf("%c",8);
      }

      if(ch != 13 && ch >= 32)
      {
         /* Add character to the string, and display it */
         printf("%c",ch);
         txt[pos] = ch;
         fflush(stdout);
         pos++;
      }
   }while(ch != 13 && pos < maxlen);

   /* Pad with spaces */
   if(pos > 0)
   {
      while(pos < maxlen)
      {
         txt[pos] = 32;
         pos++;
      }
   }

   printf("\n");
}

/*===================================================================
  id3e_process_file(file)

  Takes a filename and allows the user to edit the ID3 tag
  =================================================================*/

void id3e_process_file(char *file)
{
   ID3_TAG id3;
   int tagged = 0;
   char temptrack[3];


   /* Show the user the filename */

   printf("Processing: %s\n",file);

   /* check it's an MP3 */

   if( stricmp("MP3", &file[strlen(file)-3]) != 0)
   {
      printf("File is not an MP3\n");
      return;
   }

   /* Get its ID3 tag (if it already exists) */

   if((tagged=id3_read(file, &id3)))
      printf("File is already tagged\n");
   else
      printf("File currently has no tag\n");

   printf("\n");

   /* Edit the fields */
   printf("Edit fields: %s\n\n", tagged ? "(just press ENTER to keep existing value)" : "");

   printf("Artist  : %s%s%s ", tagged ? "[" : "", tagged ? id3.artist : "", tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(id3.artist, 30);

   printf("Title   : %s%s%s ", tagged ? "[" : "", tagged ? id3.title : "", tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(id3.title, 30);

   printf("Album   : %s%s%s ", tagged ? "[" : "", tagged ? id3.album : "", tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(id3.album, 30);

   printf("Year    : %s%s%s ", tagged ? "[" : "", tagged ? id3.year : "", tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(id3.year, 4);

   printf("Comment : %s%s%s ", tagged ? "[" : "", tagged ? id3.comment : "", tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(id3.comment, 29);

   printf("Track   : %s%d%s ", tagged ? "[" : "", tagged ? id3.track : 0, tagged ? "]" : "");
   fflush(stdout);
   id3e_get_limited_input(temptrack, 2);
   id3.track = atoi(temptrack);

   /* genre editing currently disabled */
   id3.genre = -1;

   /* Write the ID3 tag */
   id3_write(file, id3);
}

/*===================================================================
  main()
  =================================================================*/

int main(int argc, char **argv)
{
   int n;

   /* Show program title */

   printf("\n");
   printf("===========================================\n");
   printf("    ID3EDIT - Simple ID3 Editor for DOS    \n");
   printf("By Matt Craven    (c)2000 Hedgehog Software\n");
   printf("               version  %1.2f               \n",id3edit_version);
   printf("===========================================\n\n");

   /* Check we've been given at least 1 filename */

   if(argc == 1)
   {
      printf("Usage: id3edit <filename(s).mp3>\n");
      exit(-1);
   }

   /* Process the files */

   for(n=1;n<argc;n++)
      id3e_process_file(argv[n]);

   /* End nicely */

   return(0);
}
